@@ -1,6 +1,6 @@
 from __future__ import annotations
 from enum import IntEnum, IntFlag
-from typing import List, Tuple, BinaryIO
+from typing import BinaryIO
 from dataclasses import dataclass
 import struct
 import colorsys
@@ -48,7 +48,9 @@ class DeviceType(IntEnum):
     MOUSEMAT = 7
     HEADSET = 8
     HEADSET_STAND = 9
-    UNKNOWN = 10
+    GAMEPAD = 10
+    LIGHT = 11
+    UNKNOWN = 12
 
 
 class ZoneType(IntEnum):
@@ -60,7 +62,9 @@ class ZoneType(IntEnum):
 class PacketType(IntEnum):
     REQUEST_CONTROLLER_COUNT = 0
     REQUEST_CONTROLLER_DATA = 1
+    REQUEST_PROTOCOL_VERSION = 40
     SET_CLIENT_NAME = 50
+    DEVICE_LIST_UPDATED = 100
     RGBCONTROLLER_RESIZEZONE = 1000
     RGBCONTROLLER_UPDATELEDS = 1050
     RGBCONTROLLER_UPDATEZONELEDS = 1051
@@ -73,7 +77,7 @@ class OpenRGBDisconnected(ConnectionError):
     pass
 
 
-def parse_string(data: bytes, start: int = 0) -> Tuple[int, str]:
+def parse_string(data: bytes, start: int = 0) -> tuple[int, str]:
     '''
     Parses a string based on a size.
 
@@ -99,7 +103,7 @@ def pack_string(string: str) -> bytearray:
     return struct.pack(f"H{num}s", num + 1, string.encode('ascii')) + b'\x00'
 
 
-def parse_list(kind: object, data: bytearray, start: int = 0) -> Tuple[int, List]:
+def parse_list(kind: object, data: bytearray, version: int, start: int = 0) -> tuple[int, list]:
     '''
     Parses a list of objects and returns them
 
@@ -111,19 +115,19 @@ def parse_list(kind: object, data: bytearray, start: int = 0) -> Tuple[int, List
     start += struct.calcsize("H")
     things = []
     for x in range(num):
-        start, thing = kind.unpack(data, start, x)
+        start, thing = kind.unpack(data, version, start, x)
         things.append(thing)
     return start, things
 
 
-def pack_list(things: list) -> bytearray:
+def pack_list(things: list, version: int) -> bytearray:
     '''
     Packs a list of things using the things' .pack() methods
 
     :param things: a list of things to pack
     :returns: bytes ready to be used
     '''
-    return bytes(struct.pack("H", len(things))) + b''.join(thing.pack() for thing in things)
+    return bytes(struct.pack("H", len(things))) + b''.join(thing.pack(version) for thing in things)
 
 
 @dataclass
@@ -132,7 +136,7 @@ class RGBColor:
     green: int
     blue: int
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int = 0) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
@@ -141,7 +145,7 @@ class RGBColor:
         return struct.pack("BBBx", self.red, self.green, self.blue)
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0, *args) -> Tuple[int, RGBColor]:
+    def unpack(cls, data: bytearray, version: int, start: int = 0, *args) -> tuple[int, RGBColor]:
         '''
         Unpacks an RGBColor object from bytes
 
@@ -164,7 +168,7 @@ class LEDData:
     name: str
     value: int
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
@@ -176,7 +180,7 @@ class LEDData:
         )
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0, *args) -> Tuple[int, LEDData]:
+    def unpack(cls, data: bytearray, version: int, start: int = 0, *args) -> tuple[int, LEDData]:
         '''
         Creates a new LEDData object from raw bytes
 
@@ -202,7 +206,7 @@ class ModeData:
     speed: int
     direction: ModeDirections
     color_mode: ModeColors
-    colors: List[RGBColor]
+    colors: list[RGBColor]
 
     def validate(self):
         '''
@@ -225,7 +229,7 @@ class ModeData:
         except AssertionError as e:
             raise ValueError("Mode validation failed.  Values are set that are not supported by this mode") from e
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
@@ -248,12 +252,12 @@ class ModeData:
                 self.color_mode
             )
         )
-        data += pack_list(self.colors if self.colors is not None else [])
+        data += pack_list(self.colors if self.colors is not None else [], version)
         data = struct.pack("I", len(data) + struct.calcsize("I")) + data
         return data
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0, index: int = 0) -> Tuple[int, ModeData]:
+    def unpack(cls, data: bytearray, version: int, start: int = 0, index: int = 0) -> tuple[int, ModeData]:
         '''
         Creates a new ModeData object from raw bytes
 
@@ -277,11 +281,10 @@ class ModeData:
         if ModeFlags.HAS_SPEED not in buff[1]:
             buff[2], buff[3], buff[6] = None, None, None
         buff[8] = ModeColors(buff[8])
-        if ModeFlags.HAS_MODE_SPECIFIC_COLOR in buff[1]:
-            for i in range(buff[-1]):
-                start, color = RGBColor.unpack(data, start)
-                colors.append(color)
-        else:
+        for i in range(buff[-1]):
+            start, color = RGBColor.unpack(data, version, start)
+            colors.append(color)
+        if buff[-1] == 0:
             colors, buff[4], buff[5] = None, None, None
         return start, cls(index, val, *buff[:9], colors)
 
@@ -295,12 +298,12 @@ class ZoneData:
     num_leds: int
     mat_height: int
     mat_width: int
-    matrix_map: List[list] = None
-    leds: List[LEDData] = None
-    colors: List[RGBColor] = None
+    matrix_map: list[list] = None
+    leds: list[LEDData] = None
+    colors: list[RGBColor] = None
     start_idx: int = None
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
@@ -331,7 +334,7 @@ class ZoneData:
         return data
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0, *args) -> Tuple[int, ZoneData]:
+    def unpack(cls, data: bytearray, version: int, start: int = 0, *args) -> tuple[int, ZoneData]:
         '''
         Unpacks the raw data into a ZoneData object
 
@@ -357,26 +360,30 @@ class ZoneData:
 
 @dataclass
 class MetaData:
+    vendor: str
     description: str
     version: str
     serial: str
     location: str
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
         :returns: raw data ready to be sent or saved
         '''
-        return (
+        buff = (
             pack_string(self.description)
             + pack_string(self.version)
             + pack_string(self.serial)
             + pack_string(self.location)
         )
+        if version >= 1:
+            buff = pack_string(self.vendor) + buff
+        return buff
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0, *args) -> Tuple[int, MetaData]:
+    def unpack(cls, data: bytearray, version: int, start: int = 0, *args) -> tuple[int, MetaData]:
         '''
         Unpacks the raw data into a MetaData object
 
@@ -384,9 +391,11 @@ class MetaData:
         :param start: What place in the data object to start
         '''
         buff = []
-        for x in range(4):
+        for x in range(5 if version >= 1 else 4):
             start, val = parse_string(data, start)
             buff.append(val)
+        if version < 1:
+            buff = [None] + buff
         return start, cls(*buff)
 
 
@@ -395,13 +404,13 @@ class ControllerData:
     name: str
     metadata: MetaData
     device_type: DeviceType
-    leds: List[LEDData]
-    zones: List[ZoneData]
-    modes: List[ModeData]
-    colors: List[RGBColor]
+    leds: list[LEDData]
+    zones: list[ZoneData]
+    modes: list[ModeData]
+    colors: list[RGBColor]
     active_mode: int
 
-    def pack(self) -> bytearray:
+    def pack(self, version: int) -> bytearray:
         '''
         Packs itself into a bytearray ready to be sent to the SDK or saved in a profile
 
@@ -410,19 +419,19 @@ class ControllerData:
         buff = (
             struct.pack("i", self.device_type)
             + pack_string(self.name)
-            + self.metadata.pack()
+            + self.metadata.pack(version)
             + struct.pack("H", len(self.modes))
             + struct.pack("i", self.active_mode)
-            + b''.join(mode.pack()[struct.calcsize("Ii"):] for mode in self.modes)
-            + pack_list(self.zones)
-            + pack_list(self.leds)
-            + pack_list(self.colors)
+            + b''.join(mode.pack(version)[struct.calcsize("Ii"):] for mode in self.modes)
+            + pack_list(self.zones, version)
+            + pack_list(self.leds, version)
+            + pack_list(self.colors, version)
         )
         buff = struct.pack("I", len(buff) + struct.calcsize("I")) + buff
         return buff
 
     @classmethod
-    def unpack(cls, data: bytearray, start: int = 0) -> ControllerData:
+    def unpack(cls, data: bytearray, version: int, start: int = 0) -> ControllerData:
         '''
         Unpacks the raw bytes received from the SDK into a ControllerData dataclass
 
@@ -431,20 +440,23 @@ class ControllerData:
         '''
         buff = struct.unpack("Ii", data[start:start + struct.calcsize("Ii")])
         start += struct.calcsize("Ii")
-        device_type = DeviceType(buff[1])
+        try:
+            device_type = DeviceType(buff[1])
+        except ValueError:
+            device_type = DeviceType.UNKNOWN
         start, name = parse_string(data, start)
-        start, metadata = MetaData.unpack(data, start)
+        start, metadata = MetaData.unpack(data, version, start)
         buff = struct.unpack("=Hi", data[start:start + struct.calcsize("=Hi")])
         start += struct.calcsize("=Hi")
         num_modes = buff[0]
         active_mode = buff[-1]
         modes = []
         for x in range(num_modes):
-            start, mode = ModeData.unpack(data, start, x)
+            start, mode = ModeData.unpack(data, version, start, x)
             modes.append(mode)
-        start, zones = parse_list(ZoneData, data, start)
-        start, leds = parse_list(LEDData, data, start)
-        start, colors = parse_list(RGBColor, data, start)
+        start, zones = parse_list(ZoneData, data, version, start)
+        start, leds = parse_list(LEDData, data, version, start)
+        start, colors = parse_list(RGBColor, data, version, start)
         i = 0
         for zone in zones:
             zone.start_idx = i
@@ -479,13 +491,13 @@ class Profile:
     '''
     A dataclass to load, store, and pack the data found in an OpenRGB profile file.
     '''
-    controllers: List[ControllerData]
+    controllers: list[ControllerData]
 
     def pack(self) -> bytearray:
         data = bytearray()
         data += struct.pack("16sI", b'OPENRGB_PROFILE\x00', 1)
         for dev in self.controllers:
-            data += dev.data.pack()
+            data += dev.pack(0)
         return data
 
     @classmethod
@@ -502,7 +514,7 @@ class Profile:
                     break
                 size = struct.unpack("I", d)[0]
                 profile.seek(profile.tell() - struct.calcsize("I"))
-                new_data = ControllerData.unpack(profile.read(size))
+                new_data = ControllerData.unpack(profile.read(size), 0)
                 controllers.append(new_data)
             return cls(controllers)
 
@@ -550,7 +562,7 @@ class RGBContainer(RGBObject):
     :any:`Device` class or the :any:`Zone` class.
     '''
 
-    def set_colors(self, colors: List[RGBColor], start: int = 0, end: int = 0, fast: bool = False):
+    def set_colors(self, colors: list[RGBColor], start: int = 0, end: int = 0, fast: bool = False):
         '''
         Sets mutliple colors
 
